Report

Go to page content

# Dexy Run Report

## Results of your Run

This is a logfile to help you understand how dexy has processed your files and to assist with troubleshooting.

### Timing

The total elapsed time for batch 1001 was 2.53 (0.04 minutes).

### Config

This is the configuration which was used for this run:

    Directory .:
    code:
        - .R|rout

    .md|jinja|pandoc:
        - code

    .md|jinja|pandoc|-odt:
        - pandoc: { ext : .odt }
        - code

    .md|jinja|pandoc|-pdf:
        - pandoc: { ext : .pdf }
        - code

    .md|jinja|pandoc|-docx:
        - pandoc: { ext : .docx, args: '--toc' }
        - code

# 10 Slowest Tasks

- 0.681 - example.R|rout (generated)
- 0.080 - report.md|jinja|pandoc (generated)
- 0.025 - report.md|jinja (generated)
- 0.001 - report.md|jinja|pandoc|-odt (generated)
- 0.001 - report.md|jinja|pandoc|-pdf (generated)
- 0.001 - report.md|jinja|pandoc|-docx (generated)
- 0.000 - example.R ()
- 0.000 - report.md ()
- 0.000 - plot.png ()
- 0.000 - example.txt ()

# Documents

## example.R|rout ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
example.R | artifacts/37efdae66ef5056d41883121456b3c86.R | 0.0001 |  |
example.R|rout | artifacts/16229d63a9449308b5f2f45013c9b2ab.txt | 0.6812 | generated |

#### Document Log

    2012-11-19 13:28:01,143 - example.R|rout - DEBUG - Setting up FilterArtifact:example.R|rout
    2012-11-19 13:28:01,169 - example.R|rout - DEBUG - Setting hashstring for example.R|rout to 16229d63a9449308b5f2f45013c9b2ab
    2012-11-19 13:28:01,169 - example.R|rout - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,292 - example.R|rout - DEBUG - Running FilterArtifact:example.R|rout
    2012-11-19 13:28:01,292 - example.R|rout - DEBUG - Output is not cached under 16229d63a9449308b5f2f45013c9b2ab, running...
    2012-11-19 13:28:01,294 - example.R|rout - DEBUG - About to run 'R CMD BATCH --vanilla --quiet --slave --no-timing  example.R  example.txt' in 'artifacts/16229d63a9449308b5f2f45013c9b2ab/'
    2012-11-19 13:28:01,968 - example.R|rout - DEBUG - stdout is ''
    2012-11-19 13:28:01,968 - example.R|rout - DEBUG - stderr is ''
    2012-11-19 13:28:01,969 - example.R|rout - DEBUG - adding new files found in artifacts/16229d63a9449308b5f2f45013c9b2ab for example.R|rout
    2012-11-19 13:28:01,969 - example.R|rout - DEBUG - adding additional doc example.txt (created by example.R|rout)
    2012-11-19 13:28:01,970 - example.R|rout - DEBUG - adding additional doc plot.png (created by example.R|rout)
    2012-11-19 13:28:01,972 - example.R|rout - DEBUG - adding additional doc storage.json (created by example.R|rout)

## report.md|jinja|pandoc|-odt ↑

#### Arguments

    pandoc:
        ext: .odt

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |
report.md|jinja | artifacts/2a72b42ef21c8c1f4e0febeec01055a0.md | 0.0364 | generated |
report.md|jinja|pandoc | artifacts/29996ad27404cf4801ddb34257031d71.odt | 0.1607 | generated |
report.md|jinja|pandoc|-odt | artifacts/967edcbaf43c70b71d5aba20b1173d6f.odt | 0.0014 | generated |

#### Document Log

    2012-11-19 13:28:01,181 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,183 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:01,184 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,185 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,200 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 29996ad27404cf4801ddb34257031d71
    2012-11-19 13:28:01,202 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,203 - report.md|jinja|pandoc|-odt - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-odt
    2012-11-19 13:28:01,205 - report.md|jinja|pandoc|-odt - DEBUG - Setting hashstring for report.md|jinja|pandoc|-odt to 967edcbaf43c70b71d5aba20b1173d6f
    2012-11-19 13:28:01,205 - report.md|jinja|pandoc|-odt - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,208 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,211 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 0de10b0f3ac9681f6eef299e878a1c16
    2012-11-19 13:28:01,212 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,213 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,230 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to d07ecc3fda578c14aa51d97a4a9252e2
    2012-11-19 13:28:01,232 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,235 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,238 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:01,238 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,239 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,257 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 374dafaaec8b9be60e3a3b94ce9df20c
    2012-11-19 13:28:01,258 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,265 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,268 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:01,268 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,269 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,284 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to c92599097f2fed1fc118e48ed95e0bd0
    2012-11-19 13:28:01,286 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,973 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,974 - report.md|jinja - DEBUG - Output is not cached under 2a72b42ef21c8c1f4e0febeec01055a0, running...
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/2a72b42ef21c8c1f4e0febeec01055a0/, artifacts/2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,009 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,010 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,010 - report.md|jinja|pandoc - DEBUG - Output is not cached under 29996ad27404cf4801ddb34257031d71, running...
    2012-11-19 13:28:02,011 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.odt' in 'artifacts/29996ad27404cf4801ddb34257031d71/'
    2012-11-19 13:28:02,167 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:02,169 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:02,172 - report.md|jinja|pandoc|-odt - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-odt
    2012-11-19 13:28:02,172 - report.md|jinja|pandoc|-odt - DEBUG - Output is not cached under 967edcbaf43c70b71d5aba20b1173d6f, running...
    2012-11-19 13:28:02,175 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:02,176 - report.md|jinja - DEBUG - Output is not cached under 0de10b0f3ac9681f6eef299e878a1c16, running...
    2012-11-19 13:28:02,180 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/0de10b0f3ac9681f6eef299e878a1c16/, artifacts/0de10b0f3ac9681f6eef299e878a1c16
    2012-11-19 13:28:02,181 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:02,182 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,201 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,201 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,203 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,204 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,205 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,205 - report.md|jinja|pandoc - DEBUG - Output is not cached under d07ecc3fda578c14aa51d97a4a9252e2, running...
    2012-11-19 13:28:02,207 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.html' in 'artifacts/d07ecc3fda578c14aa51d97a4a9252e2/'
    2012-11-19 13:28:02,254 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:02,255 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:02,260 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:02,261 - report.md|jinja - DEBUG - Output is not cached under 999ed730dae84c7227d1fd380e280f57, running...
    2012-11-19 13:28:02,265 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/999ed730dae84c7227d1fd380e280f57/, artifacts/999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:02,266 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:02,266 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,285 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,285 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,287 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,288 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,289 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,289 - report.md|jinja|pandoc - DEBUG - Output is not cached under 374dafaaec8b9be60e3a3b94ce9df20c, running...
    2012-11-19 13:28:02,291 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.pdf' in 'artifacts/374dafaaec8b9be60e3a3b94ce9df20c/'
    2012-11-19 13:28:03,173 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:03,174 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:03,179 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:03,180 - report.md|jinja - DEBUG - Output is not cached under 679cc4370ea3018f8d90b3a36b8dc579, running...
    2012-11-19 13:28:03,180 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/679cc4370ea3018f8d90b3a36b8dc579/, artifacts/679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:03,183 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:03,183 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:03,200 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:03,200 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:03,202 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:03,204 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:03,204 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:03,205 - report.md|jinja|pandoc - DEBUG - Output is not cached under c92599097f2fed1fc118e48ed95e0bd0, running...
    2012-11-19 13:28:03,206 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc --toc report.md -o report.docx' in 'artifacts/c92599097f2fed1fc118e48ed95e0bd0/'
    2012-11-19 13:28:03,281 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:03,283 - report.md|jinja|pandoc - DEBUG - stderr is ''

## report.md|jinja|pandoc ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0001 |  |
report.md|jinja | artifacts/0de10b0f3ac9681f6eef299e878a1c16.md | 0.0298 | generated |
report.md|jinja|pandoc | artifacts/d07ecc3fda578c14aa51d97a4a9252e2.html | 0.0521 | generated |

#### Document Log

    2012-11-19 13:28:01,185 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,200 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 29996ad27404cf4801ddb34257031d71
    2012-11-19 13:28:01,202 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,213 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,230 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to d07ecc3fda578c14aa51d97a4a9252e2
    2012-11-19 13:28:01,232 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,239 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,257 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 374dafaaec8b9be60e3a3b94ce9df20c
    2012-11-19 13:28:01,258 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,269 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,284 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to c92599097f2fed1fc118e48ed95e0bd0
    2012-11-19 13:28:01,286 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:02,010 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,010 - report.md|jinja|pandoc - DEBUG - Output is not cached under 29996ad27404cf4801ddb34257031d71, running...
    2012-11-19 13:28:02,011 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.odt' in 'artifacts/29996ad27404cf4801ddb34257031d71/'
    2012-11-19 13:28:02,167 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:02,169 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:02,205 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,205 - report.md|jinja|pandoc - DEBUG - Output is not cached under d07ecc3fda578c14aa51d97a4a9252e2, running...
    2012-11-19 13:28:02,207 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.html' in 'artifacts/d07ecc3fda578c14aa51d97a4a9252e2/'
    2012-11-19 13:28:02,254 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:02,255 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:02,289 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,289 - report.md|jinja|pandoc - DEBUG - Output is not cached under 374dafaaec8b9be60e3a3b94ce9df20c, running...
    2012-11-19 13:28:02,291 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.pdf' in 'artifacts/374dafaaec8b9be60e3a3b94ce9df20c/'
    2012-11-19 13:28:03,173 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:03,174 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:03,204 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:03,205 - report.md|jinja|pandoc - DEBUG - Output is not cached under c92599097f2fed1fc118e48ed95e0bd0, running...
    2012-11-19 13:28:03,206 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc --toc report.md -o report.docx' in 'artifacts/c92599097f2fed1fc118e48ed95e0bd0/'
    2012-11-19 13:28:03,281 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:03,283 - report.md|jinja|pandoc - DEBUG - stderr is ''

## report.md|jinja|pandoc|-pdf ↑

#### Arguments

    pandoc:
        ext: .pdf

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0001 |  |
report.md|jinja | artifacts/999ed730dae84c7227d1fd380e280f57.md | 0.0291 | generated |
report.md|jinja|pandoc | artifacts/374dafaaec8b9be60e3a3b94ce9df20c.pdf | 0.8870 | generated |
report.md|jinja|pandoc|-pdf | artifacts/366f465f37a9d65c0bee00cd76d061df.pdf | 0.0014 | generated |

#### Document Log

    2012-11-19 13:28:01,181 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,183 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:01,184 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,185 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,200 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 29996ad27404cf4801ddb34257031d71
    2012-11-19 13:28:01,202 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,208 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,211 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 0de10b0f3ac9681f6eef299e878a1c16
    2012-11-19 13:28:01,212 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,213 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,230 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to d07ecc3fda578c14aa51d97a4a9252e2
    2012-11-19 13:28:01,232 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,235 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,238 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:01,238 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,239 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,257 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 374dafaaec8b9be60e3a3b94ce9df20c
    2012-11-19 13:28:01,258 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,260 - report.md|jinja|pandoc|-pdf - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-pdf
    2012-11-19 13:28:01,262 - report.md|jinja|pandoc|-pdf - DEBUG - Setting hashstring for report.md|jinja|pandoc|-pdf to 366f465f37a9d65c0bee00cd76d061df
    2012-11-19 13:28:01,262 - report.md|jinja|pandoc|-pdf - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,265 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,268 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:01,268 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,269 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,284 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to c92599097f2fed1fc118e48ed95e0bd0
    2012-11-19 13:28:01,286 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,973 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,974 - report.md|jinja - DEBUG - Output is not cached under 2a72b42ef21c8c1f4e0febeec01055a0, running...
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/2a72b42ef21c8c1f4e0febeec01055a0/, artifacts/2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,009 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,010 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,010 - report.md|jinja|pandoc - DEBUG - Output is not cached under 29996ad27404cf4801ddb34257031d71, running...
    2012-11-19 13:28:02,011 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.odt' in 'artifacts/29996ad27404cf4801ddb34257031d71/'
    2012-11-19 13:28:02,167 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:02,169 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:02,175 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:02,176 - report.md|jinja - DEBUG - Output is not cached under 0de10b0f3ac9681f6eef299e878a1c16, running...
    2012-11-19 13:28:02,180 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/0de10b0f3ac9681f6eef299e878a1c16/, artifacts/0de10b0f3ac9681f6eef299e878a1c16
    2012-11-19 13:28:02,181 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:02,182 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,201 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,201 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,203 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,204 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,205 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,205 - report.md|jinja|pandoc - DEBUG - Output is not cached under d07ecc3fda578c14aa51d97a4a9252e2, running...
    2012-11-19 13:28:02,207 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.html' in 'artifacts/d07ecc3fda578c14aa51d97a4a9252e2/'
    2012-11-19 13:28:02,254 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:02,255 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:02,260 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:02,261 - report.md|jinja - DEBUG - Output is not cached under 999ed730dae84c7227d1fd380e280f57, running...
    2012-11-19 13:28:02,265 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/999ed730dae84c7227d1fd380e280f57/, artifacts/999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:02,266 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:02,266 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,285 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,285 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,287 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,288 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,289 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,289 - report.md|jinja|pandoc - DEBUG - Output is not cached under 374dafaaec8b9be60e3a3b94ce9df20c, running...
    2012-11-19 13:28:02,291 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.pdf' in 'artifacts/374dafaaec8b9be60e3a3b94ce9df20c/'
    2012-11-19 13:28:03,173 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:03,174 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:03,177 - report.md|jinja|pandoc|-pdf - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-pdf
    2012-11-19 13:28:03,178 - report.md|jinja|pandoc|-pdf - DEBUG - Output is not cached under 366f465f37a9d65c0bee00cd76d061df, running...
    2012-11-19 13:28:03,179 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:03,180 - report.md|jinja - DEBUG - Output is not cached under 679cc4370ea3018f8d90b3a36b8dc579, running...
    2012-11-19 13:28:03,180 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/679cc4370ea3018f8d90b3a36b8dc579/, artifacts/679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:03,183 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:03,183 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:03,200 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:03,200 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:03,202 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:03,204 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:03,204 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:03,205 - report.md|jinja|pandoc - DEBUG - Output is not cached under c92599097f2fed1fc118e48ed95e0bd0, running...
    2012-11-19 13:28:03,206 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc --toc report.md -o report.docx' in 'artifacts/c92599097f2fed1fc118e48ed95e0bd0/'
    2012-11-19 13:28:03,281 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:03,283 - report.md|jinja|pandoc - DEBUG - stderr is ''

## report.md|jinja|pandoc|-docx ↑

#### Arguments

    pandoc:
        ext: .docx
        args: --toc

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |
report.md|jinja | artifacts/679cc4370ea3018f8d90b3a36b8dc579.md | 0.0248 | generated |
report.md|jinja|pandoc | artifacts/c92599097f2fed1fc118e48ed95e0bd0.docx | 0.0803 | generated |
report.md|jinja|pandoc|-docx | artifacts/d402fc4af60607659294398faf602078.docx | 0.0009 | generated |

#### Document Log

    2012-11-19 13:28:01,181 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,183 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:01,184 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,185 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,200 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 29996ad27404cf4801ddb34257031d71
    2012-11-19 13:28:01,202 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,208 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,211 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 0de10b0f3ac9681f6eef299e878a1c16
    2012-11-19 13:28:01,212 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,213 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,230 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to d07ecc3fda578c14aa51d97a4a9252e2
    2012-11-19 13:28:01,232 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,235 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,238 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:01,238 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,239 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,257 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 374dafaaec8b9be60e3a3b94ce9df20c
    2012-11-19 13:28:01,258 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,265 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,268 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:01,268 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,269 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:01,284 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to c92599097f2fed1fc118e48ed95e0bd0
    2012-11-19 13:28:01,286 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,287 - report.md|jinja|pandoc|-docx - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-docx
    2012-11-19 13:28:01,289 - report.md|jinja|pandoc|-docx - DEBUG - Setting hashstring for report.md|jinja|pandoc|-docx to d402fc4af60607659294398faf602078
    2012-11-19 13:28:01,289 - report.md|jinja|pandoc|-docx - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:01,973 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:01,974 - report.md|jinja - DEBUG - Output is not cached under 2a72b42ef21c8c1f4e0febeec01055a0, running...
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/2a72b42ef21c8c1f4e0febeec01055a0/, artifacts/2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:01,975 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:01,976 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:01,977 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,004 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,005 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,009 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,010 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,010 - report.md|jinja|pandoc - DEBUG - Output is not cached under 29996ad27404cf4801ddb34257031d71, running...
    2012-11-19 13:28:02,011 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.odt' in 'artifacts/29996ad27404cf4801ddb34257031d71/'
    2012-11-19 13:28:02,167 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:02,169 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:02,175 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:02,176 - report.md|jinja - DEBUG - Output is not cached under 0de10b0f3ac9681f6eef299e878a1c16, running...
    2012-11-19 13:28:02,180 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/0de10b0f3ac9681f6eef299e878a1c16/, artifacts/0de10b0f3ac9681f6eef299e878a1c16
    2012-11-19 13:28:02,181 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:02,182 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:02,183 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:02,184 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,201 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,201 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,202 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,203 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,204 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,205 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,205 - report.md|jinja|pandoc - DEBUG - Output is not cached under d07ecc3fda578c14aa51d97a4a9252e2, running...
    2012-11-19 13:28:02,207 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.html' in 'artifacts/d07ecc3fda578c14aa51d97a4a9252e2/'
    2012-11-19 13:28:02,254 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:02,255 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:02,260 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:02,261 - report.md|jinja - DEBUG - Output is not cached under 999ed730dae84c7227d1fd380e280f57, running...
    2012-11-19 13:28:02,265 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/999ed730dae84c7227d1fd380e280f57/, artifacts/999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:02,266 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:02,266 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:02,267 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:02,268 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:02,285 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:02,285 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:02,286 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:02,287 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:02,288 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:02,289 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:02,289 - report.md|jinja|pandoc - DEBUG - Output is not cached under 374dafaaec8b9be60e3a3b94ce9df20c, running...
    2012-11-19 13:28:02,291 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc  report.md -o report.pdf' in 'artifacts/374dafaaec8b9be60e3a3b94ce9df20c/'
    2012-11-19 13:28:03,173 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:03,174 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:03,179 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:03,180 - report.md|jinja - DEBUG - Output is not cached under 679cc4370ea3018f8d90b3a36b8dc579, running...
    2012-11-19 13:28:03,180 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/679cc4370ea3018f8d90b3a36b8dc579/, artifacts/679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:03,181 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:03,182 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:03,183 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:03,183 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:03,200 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:03,200 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', '/example.txt', '/plot.png', '/storage.json', 'example.R-rout.txt', 'example.R|rout', 'example.txt', 'plot.png', 'storage.json']
    2012-11-19 13:28:03,201 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:03,202 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:03,204 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:03,204 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:03,205 - report.md|jinja|pandoc - DEBUG - Output is not cached under c92599097f2fed1fc118e48ed95e0bd0, running...
    2012-11-19 13:28:03,206 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc --toc report.md -o report.docx' in 'artifacts/c92599097f2fed1fc118e48ed95e0bd0/'
    2012-11-19 13:28:03,281 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:03,283 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:03,286 - report.md|jinja|pandoc|-docx - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-docx
    2012-11-19 13:28:03,286 - report.md|jinja|pandoc|-docx - DEBUG - Output is not cached under d402fc4af60607659294398faf602078, running...

## example.txt ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
example.txt | artifacts/67ca147287010eee7af5529b040a79ab.txt | 0.0000 |  |

#### Document Log

    2012-11-19 13:28:01,969 - example.txt - DEBUG - Setting up InitialVirtualArtifact:example.txt
    2012-11-19 13:28:01,970 - example.txt - DEBUG - Setting hashstring for example.txt to 67ca147287010eee7af5529b040a79ab
    2012-11-19 13:28:01,970 - example.txt - DEBUG - setting up output data of class GenericData

## plot.png ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
plot.png | artifacts/a4249c9911b3be397dc5ab29237545fe.png | 0.0000 |  |

#### Document Log

    2012-11-19 13:28:01,971 - plot.png - DEBUG - Setting up InitialVirtualArtifact:plot.png
    2012-11-19 13:28:01,971 - plot.png - DEBUG - Setting hashstring for plot.png to a4249c9911b3be397dc5ab29237545fe
    2012-11-19 13:28:01,971 - plot.png - DEBUG - setting up output data of class GenericData

## storage.json ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
storage.json | artifacts/6248a02508321609e66ae3d947f25aaa.json | 0.0000 |  |

#### Document Log

    2012-11-19 13:28:01,972 - storage.json - DEBUG - Setting up InitialVirtualArtifact:storage.json
    2012-11-19 13:28:01,972 - storage.json - DEBUG - Setting hashstring for storage.json to 6248a02508321609e66ae3d947f25aaa
    2012-11-19 13:28:01,972 - storage.json - DEBUG - setting up output data of class GenericData